===============
entropyrate
===============

.. figure:: https://img.shields.io/pypi/dm/entropyrate.svg
   :alt: entropyrate PyPI Downloads
.. figure:: https://img.shields.io/pypi/v/entropyrate.svg
   :alt: entropyrate version


.. image:: http://zed.uchicago.edu/logo/logozed1.png
   :height: 400px
   :scale: 50 %
   :alt: alternate text
   :align: center


.. class:: no-web no-pdf

:Author: ZeD@UChicago <zed.uchicago.edu>
:Description: Python wrappers for computing entropy rate of ergodic stationary finite valued processes. An example will be placed in the enviroment's folder upon installation.


**Usage:**
	
.. code-block:: python

	import entropyrate.entropyrate as e



